==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h <==
// public abstract class soot.jimple.toolkits.pointer.nativemethods.NativeMethodClass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object;

typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct {
	jboolean	DEBUG;
};
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$defaultMethod$3c7c97e1589bbf93(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h <==
// public abstract class soot.jimple.toolkits.pointer.nativemethods.NativeMethodClass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object;

typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype;

// Class fields structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct {
	jboolean	DEBUG;
};
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$fields_struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$class_fields;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$method$defaultMethod$3c7c97e1589bbf93(_jc_env *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass_H_ */
